@@ -23,8 +23,8 @@ from fedjax.core.typing import Batch
 from fedjax.core.typing import Params
 from fedjax.core.typing import PRNGKey
 from fedjax.core.typing import Updates
-import frozendict
 import haiku as hk
+import immutabledict
 import jax
 import jax.numpy as jnp
 
@@ -57,8 +57,8 @@ class Model:
     apply_fn: Function that produces model predictions for input batch.
     loss_fn: Loss function that takes input batch and model predictions and
       returns scalar loss.
-    reg_fn: Regularization function that takes parameters in and returns a
-      scalar regularizer value.
+    reg_fn: Regularization function that takes parameters in and returns
+      a scalar regularizer value.
     metrics_fn_map: Ordered mapping of metric names to metric functions that
       take input batch and model predictions and return metric values.
     train_kwargs: Keyword arguments passed to apply for training.
@@ -69,9 +69,9 @@ class Model:
   apply_fn: Callable[..., jnp.ndarray]
   loss_fn: MetricsFn
   reg_fn: Callable[[Params], jnp.ndarray] = lambda p: 0.
-  metrics_fn_map: Mapping[str, MetricsFn] = frozendict.frozendict()
-  train_kwargs: Mapping[str, Any] = frozendict.frozendict()
-  test_kwargs: Mapping[str, Any] = frozendict.frozendict()
+  metrics_fn_map: Mapping[str, MetricsFn] = immutabledict.immutabledict()
+  train_kwargs: Mapping[str, Any] = immutabledict.immutabledict()
+  test_kwargs: Mapping[str, Any] = immutabledict.immutabledict()
   modify_grads_fn: Callable[[Updates], Updates] = lambda g: g
 
   def init_params(self, rng: PRNGKey) -> Params:
@@ -117,9 +117,9 @@ def _get_defaults(reg_fn, metrics_fn_map, train_kwargs, test_kwargs):
   metrics_fn_map = metrics_fn_map or collections.OrderedDict()
   train_kwargs = train_kwargs or {}
   test_kwargs = test_kwargs or {}
-  frozen_metrics_fn_map = frozendict.frozendict(metrics_fn_map)
-  frozen_train_kwargs = frozendict.frozendict(train_kwargs)
-  frozen_test_kwargs = frozendict.frozendict(test_kwargs)
+  frozen_metrics_fn_map = immutabledict.immutabledict(metrics_fn_map)
+  frozen_train_kwargs = immutabledict.immutabledict(train_kwargs)
+  frozen_test_kwargs = immutabledict.immutabledict(test_kwargs)
   return reg_fn, frozen_metrics_fn_map, frozen_train_kwargs, frozen_test_kwargs
 
 
@@ -131,8 +131,7 @@ def create_model_from_haiku(
     metrics_fn_map: Optional[Mapping[str, MetricsFn]] = None,
     train_kwargs: Optional[Mapping[str, Any]] = None,
     test_kwargs: Optional[Mapping[str, Any]] = None,
-    non_trainable_module_names: Tuple[str] = ()
-) -> Model:
+    non_trainable_module_names: Tuple[str] = ()) -> Model:  # pytype: disable=annotation-type-mismatch
   """Creates Model after applying defaults and haiku specific preprocessing.
 
   Args:
@@ -140,8 +139,8 @@ def create_model_from_haiku(
     sample_batch: Example input batch used to determine model parameter shapes.
     loss_fn: Loss function that takes input batch and model predictions and
       returns scalar loss.
-    reg_fn: Regularization function that takes parameters in and returns a
-      scalar regularizer value. Defaults to no regularization.
+    reg_fn: Regularization function that takes parameters in and returns
+      a scalar regularizer value. Defaults to no regularization.
     metrics_fn_map: Ordered mapping of metric names to metric functions that
       take input batch and model predictions and return metric values that will
       be freezed for immutability. Defaults to empty frozen dictionary.
@@ -190,8 +189,8 @@ def create_model_from_stax(
     loss_fn: Loss function that takes input batch and model predictions and
       returns scalar loss.
     input_key: Key name for the input from batch mapping.
-    reg_fn: Regularization function that takes parameters in and returns a
-      scalar regularizer value. Defaults to no regularization.
+    reg_fn: Regularization function that takes parameters in and returns
+      a scalar regularizer value. Defaults to no regularization.
     metrics_fn_map: Ordered mapping of metric names to metric functions that
       take input batch and model predictions and return metric values that will
       be freezed for immutability. Defaults to empty frozen dictionary.
