@@ -50,10 +50,11 @@ class L2Regularizer(Regularizer):
       regularization strength for each parameter.
   """
 
-  def __init__(self,
-               center_params: Optional[Params] = None,
-               weight: float = 1.0,
-               param_weights: Optional[Params] = None):
+  def __init__(
+      self,
+      center_params: Optional[Params] = None,
+      weight: float = 1.0,
+      param_weights: Optional[Params] = None):
     super().__init__(center_params)
     self._weight = weight
     self._param_weights = param_weights
@@ -65,8 +66,7 @@ class L2Regularizer(Regularizer):
 
     if self._param_weights:
       param_weight_leaves, _ = jax.tree_flatten(self._param_weights)
-      return sum(
-          jnp.vdot(pw, jnp.square(x))
-          for pw, x in zip(param_weight_leaves, leaves)) * self._weight
+      return sum(jnp.vdot(pw, jnp.square(x))
+                 for pw, x in zip(param_weight_leaves, leaves)) * self._weight
 
     return sum(jnp.vdot(x, x) for x in leaves) * self._weight
